@@ -2,7 +2,7 @@
  *
  * Different ways of setting up a backend connection.
  *
- * Copyright (c) 2001-2017, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2019, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -12,13 +12,16 @@
 
 #include <stdexcept>
 
+extern "C"
+{
 #include "libpq-fe.h"
+}
 
 #include "pqxx/connection"
 
 
 pqxx::connectionpolicy::connectionpolicy(const std::string &opts) :
-  m_options(opts)
+  m_options{opts}
 {
 }
 
@@ -33,12 +36,12 @@ pqxx::connectionpolicy::normalconnect(handle orig)
 {
   if (orig) return orig;
   orig = PQconnectdb(options().c_str());
-  if (!orig) throw std::bad_alloc();
+  if (orig == nullptr) throw std::bad_alloc{};
   if (PQstatus(orig) != CONNECTION_OK)
   {
-    const std::string msg(PQerrorMessage(orig));
+    const std::string msg{PQerrorMessage(orig)};
     PQfinish(orig);
-    throw broken_connection(msg);
+    throw broken_connection{msg};
   }
   return orig;
 }
@@ -84,9 +87,9 @@ pqxx::connect_direct::do_startconnect(handle orig)
   orig = normalconnect(orig);
   if (PQstatus(orig) != CONNECTION_OK)
   {
-    const std::string msg(PQerrorMessage(orig));
+    const std::string msg{PQerrorMessage(orig)};
     do_disconnect(orig);
-    throw broken_connection(msg);
+    throw broken_connection{msg};
   }
   return orig;
 }
@@ -100,22 +103,22 @@ pqxx::connect_lazy::do_completeconnect(handle orig)
 
 
 pqxx::connect_async::connect_async(const std::string &opts) :
-  connectionpolicy(opts),
-  m_connecting(false)
+  connectionpolicy{opts},
+  m_connecting{false}
 {
 }
 
 pqxx::connectionpolicy::handle
 pqxx::connect_async::do_startconnect(handle orig)
 {
-  if (orig) return orig;	// Already connecting or connected
+  if (orig != nullptr) return orig;	// Already connecting or connected.
   m_connecting = false;
   orig = PQconnectStart(options().c_str());
-  if (!orig) throw std::bad_alloc();
+  if (orig == nullptr) throw std::bad_alloc{};
   if (PQstatus(orig) == CONNECTION_BAD)
   {
     do_dropconnect(orig);
-    throw broken_connection(std::string(PQerrorMessage(orig)));
+    throw broken_connection{std::string{PQerrorMessage(orig)}};
   }
   m_connecting = true;
   return orig;
@@ -125,9 +128,9 @@ pqxx::connect_async::do_startconnect(handle orig)
 pqxx::connectionpolicy::handle
 pqxx::connect_async::do_completeconnect(handle orig)
 {
-  const bool makenew = !orig;
+  const bool makenew = (orig == nullptr);
   if (makenew) orig = do_startconnect(orig);
-  if (!m_connecting) return orig;
+  if (not m_connecting) return orig;
 
   // Our "attempt to connect" state ends here, for better or for worse
   m_connecting = false;
@@ -140,7 +143,7 @@ pqxx::connect_async::do_completeconnect(handle orig)
     {
     case PGRES_POLLING_FAILED:
       if (makenew) do_disconnect(orig);
-      throw broken_connection(std::string(PQerrorMessage(orig)));
+      throw broken_connection{std::string{PQerrorMessage(orig)}};
 
     case PGRES_POLLING_READING:
       internal::wait_read(orig);
@@ -175,5 +178,5 @@ pqxx::connect_async::do_dropconnect(handle orig) noexcept
 
 bool pqxx::connect_async::is_ready(handle h) const noexcept
 {
-  return h != nullptr && !m_connecting;
+  return h != nullptr and not m_connecting;
 }
