@@ -2,7 +2,7 @@
  *
  * Throughput-optimized query interface.
  *
- * Copyright (c) 2003-2018, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2019, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -22,19 +22,18 @@
 using namespace pqxx;
 using namespace pqxx::internal;
 
-#define pqxxassert(ARG) /* ignore */
 
 namespace
 {
-const std::string theSeparator("; ");
-const std::string theDummyValue("1");
-const std::string theDummyQuery("SELECT " + theDummyValue + theSeparator);
+const std::string theSeparator{"; "};
+const std::string theDummyValue{"1"};
+const std::string theDummyQuery{"SELECT " + theDummyValue + theSeparator};
 }
 
 
 pqxx::pipeline::pipeline(transaction_base &t, const std::string &Name) :
-  namedclass("pipeline", Name),
-  transactionfocus(t)
+  namedclass{"pipeline", Name},
+  transactionfocus{t}
 {
   m_issuedrange = make_pair(m_queries.end(), m_queries.end());
   attach();
@@ -50,7 +49,7 @@ pqxx::pipeline::~pipeline() noexcept
 
 void pqxx::pipeline::attach()
 {
-  if (!registered()) register_me();
+  if (not registered()) register_me();
 }
 
 
@@ -64,8 +63,6 @@ pipeline::query_id pqxx::pipeline::insert(const std::string &q)
 {
   attach();
   const query_id qid = generate_id();
-  pqxxassert(qid > 0);
-  pqxxassert(m_queries.lower_bound(qid)==m_queries.end());
   const auto i = m_queries.insert(std::make_pair(qid,Query(q))).first;
 
   if (m_issuedrange.second == m_queries.end())
@@ -75,13 +72,10 @@ pipeline::query_id pqxx::pipeline::insert(const std::string &q)
   }
   m_num_waiting++;
 
-  pqxxassert(m_issuedrange.first != m_queries.end());
-  pqxxassert(m_issuedrange.second != m_queries.end());
-
   if (m_num_waiting > m_retain)
   {
     if (have_pending()) receive_if_available();
-    if (!have_pending()) issue();
+    if (not have_pending()) issue();
   }
 
   return qid;
@@ -91,25 +85,18 @@ pipeline::query_id pqxx::pipeline::insert(const std::string &q)
 void pqxx::pipeline::complete()
 {
   if (have_pending()) receive(m_issuedrange.second);
-  if (m_num_waiting && (m_error == qid_limit()))
+  if (m_num_waiting and (m_error == qid_limit()))
   {
-    pqxxassert(!have_pending());
     issue();
-    pqxxassert(!m_num_waiting);
-    pqxxassert(have_pending());
-    pqxxassert(m_issuedrange.second == m_queries.end());
     receive(m_queries.end());
-    pqxxassert((m_error!=qid_limit()) || !have_pending());
   }
   detach();
-  pqxxassert((m_num_waiting == 0) || (m_error != qid_limit()));
-  pqxxassert(!m_dummy_pending);
 }
 
 
 void pqxx::pipeline::flush()
 {
-  if (!m_queries.empty())
+  if (not m_queries.empty())
   {
     if (have_pending()) receive(m_issuedrange.second);
     m_issuedrange.first = m_issuedrange.second = m_queries.end();
@@ -136,18 +123,18 @@ void pqxx::pipeline::cancel()
 bool pqxx::pipeline::is_finished(pipeline::query_id q) const
 {
   if (m_queries.find(q) == m_queries.end())
-    throw std::logic_error(
-      "Requested status for unknown query " + to_string(q));
+    throw std::logic_error{
+      "Requested status for unknown query '" + to_string(q) + "'."};
   return
-	(QueryMap::const_iterator(m_issuedrange.first)==m_queries.end()) ||
-	(q < m_issuedrange.first->first && q < m_error);
+	(QueryMap::const_iterator(m_issuedrange.first)==m_queries.end()) or
+	(q < m_issuedrange.first->first and q < m_error);
 }
 
 
 std::pair<pipeline::query_id, result> pqxx::pipeline::retrieve()
 {
   if (m_queries.empty())
-    throw std::logic_error("Attempt to retrieve result from empty pipeline");
+    throw std::logic_error{"Attempt to retrieve result from empty pipeline."};
   return retrieve(std::begin(m_queries));
 }
 
@@ -155,9 +142,9 @@ std::pair<pipeline::query_id, result> pqxx::pipeline::retrieve()
 int pqxx::pipeline::retain(int retain_max)
 {
   if (retain_max < 0)
-    throw range_error(
+    throw range_error{
 	"Attempt to make pipeline retain " +
-	to_string(retain_max) + " queries");
+	to_string(retain_max) + " queries"};
 
   const int oldvalue = m_retain;
   m_retain = retain_max;
@@ -171,7 +158,7 @@ int pqxx::pipeline::retain(int retain_max)
 void pqxx::pipeline::resume()
 {
   if (have_pending()) receive_if_available();
-  if (!have_pending() && m_num_waiting)
+  if (not have_pending() and m_num_waiting)
   {
     issue();
     receive_if_available();
@@ -182,7 +169,7 @@ void pqxx::pipeline::resume()
 pipeline::query_id pqxx::pipeline::generate_id()
 {
   if (m_q_id == qid_limit())
-    throw std::overflow_error("Too many queries went through pipeline");
+    throw std::overflow_error{"Too many queries went through pipeline."};
   ++m_q_id;
   return m_q_id;
 }
@@ -191,11 +178,6 @@ pipeline::query_id pqxx::pipeline::generate_id()
 
 void pqxx::pipeline::issue()
 {
-  pqxxassert(m_num_waiting);
-  pqxxassert(!have_pending());
-  pqxxassert(!m_dummy_pending);
-  pqxxassert(m_num_waiting);
-
   // TODO: Wrap in nested transaction if available, for extra "replayability"
 
   // Retrieve that null result for the last query, if needed
@@ -206,17 +188,17 @@ void pqxx::pipeline::issue()
 
   // Start with oldest query (lowest id) not in previous issue range
   auto oldest = m_issuedrange.second;
-  pqxxassert(oldest != m_queries.end());
 
   // Construct cumulative query string for entire batch
   std::string cum = separated_list(
-          theSeparator, oldest, m_queries.end(), getquery());
+          theSeparator, oldest, m_queries.end(),
+          [](QueryMap::const_iterator i){return i->second.get_query();});
   const auto num_issued = QueryMap::size_type(std::distance(
 	oldest, m_queries.end()));
   const bool prepend_dummy = (num_issued > 1);
   if (prepend_dummy) cum = theDummyQuery + cum;
 
-  gate::connection_pipeline(m_trans.conn()).start_exec(cum);
+  gate::connection_pipeline{m_trans.conn()}.start_exec(cum);
 
   // Since we managed to send out these queries, update state to reflect this
   m_dummy_pending = prepend_dummy;
@@ -229,20 +211,17 @@ void pqxx::pipeline::issue()
 void pqxx::pipeline::internal_error(const std::string &err)
 {
   set_error_at(0);
-  throw pqxx::internal_error(err);
+  throw pqxx::internal_error{err};
 }
 
 
 bool pqxx::pipeline::obtain_result(bool expect_none)
 {
-  pqxxassert(!m_dummy_pending);
-  pqxxassert(!m_queries.empty());
-
-  gate::connection_pipeline gate(m_trans.conn());
+  gate::connection_pipeline gate{m_trans.conn()};
   const auto r = gate.get_result();
-  if (!r)
+  if (r == nullptr)
   {
-    if (have_pending() && !expect_none)
+    if (have_pending() and not expect_none)
     {
       set_error_at(m_issuedrange.first->first);
       m_issuedrange.second = m_issuedrange.first;
@@ -250,20 +229,20 @@ bool pqxx::pipeline::obtain_result(bool expect_none)
     return false;
   }
 
-  pqxxassert(r);
   const result res = gate::result_creation::create(
-	r, std::begin(m_queries)->second.get_query());
+	r, std::begin(m_queries)->second.get_query(),
+        internal::enc_group(m_trans.conn().encoding_id()));
 
-  if (!have_pending())
+  if (not have_pending())
   {
     set_error_at(std::begin(m_queries)->first);
-    throw std::logic_error(
-      "Got more results from pipeline than there were queries");
+    throw std::logic_error{
+      "Got more results from pipeline than there were queries."};
   }
 
   // Must be the result for the oldest pending query
-  if (!m_issuedrange.first->second.get_result().empty())
-    internal_error("multiple results for one query");
+  if (not m_issuedrange.first->second.get_result().empty())
+    internal_error("Multiple results for one query.");
 
   m_issuedrange.first->second.set_result(res);
   ++m_issuedrange.first;
@@ -274,20 +253,22 @@ bool pqxx::pipeline::obtain_result(bool expect_none)
 
 void pqxx::pipeline::obtain_dummy()
 {
-  pqxxassert(m_dummy_pending);
-  gate::connection_pipeline gate(m_trans.conn());
+  gate::connection_pipeline gate{m_trans.conn()};
   const auto r = gate.get_result();
   m_dummy_pending = false;
 
-  if (!r)
-    internal_error("pipeline got no result from backend when it expected one");
+  if (r == nullptr)
+    internal_error("Pipeline got no result from backend when it expected one.");
 
-  result R = gate::result_creation::create(r, "[DUMMY PIPELINE QUERY]");
+  result R = gate::result_creation::create(
+        r,
+        "[DUMMY PIPELINE QUERY]",
+        internal::enc_group(m_trans.conn().encoding_id()));
 
   bool OK = false;
   try
   {
-    gate::result_creation(R).check_status();
+    gate::result_creation{R}.check_status();
     OK = true;
   }
   catch (const sql_error &)
@@ -296,10 +277,10 @@ void pqxx::pipeline::obtain_dummy()
   if (OK)
   {
     if (R.size() > 1)
-      internal_error("unexpected result for dummy query in pipeline");
+      internal_error("Unexpected result for dummy query in pipeline.");
 
-    if (std::string(R.at(0).at(0).c_str()) != theDummyValue)
-      internal_error("dummy query in pipeline returned unexpected value");
+    if (std::string{R.at(0).at(0).c_str()} != theDummyValue)
+      internal_error("Dummy query in pipeline returned unexpected value.");
     return;
   }
 
@@ -324,10 +305,6 @@ void pqxx::pipeline::obtain_dummy()
   m_num_waiting += int(std::distance(m_issuedrange.first, stop));
   m_issuedrange.second = m_issuedrange.first;
 
-  pqxxassert(!m_dummy_pending);
-  pqxxassert(!have_pending());
-  pqxxassert(m_num_waiting > 0);
-
   // Issue queries in failed batch one at a time.
   unregister_me();
   try
@@ -336,29 +313,21 @@ void pqxx::pipeline::obtain_dummy()
     {
       m_num_waiting--;
       const std::string &query = m_issuedrange.first->second.get_query();
-      const result res(m_trans.exec(query));
+      const result res{m_trans.exec(query)};
       m_issuedrange.first->second.set_result(res);
-      gate::result_creation(res).check_status();
+      gate::result_creation{res}.check_status();
       ++m_issuedrange.first;
     }
     while (m_issuedrange.first != stop);
   }
   catch (const std::exception &)
   {
-    pqxxassert(m_issuedrange.first != m_queries.end());
-
     const query_id thud = m_issuedrange.first->first;
     ++m_issuedrange.first;
     m_issuedrange.second = m_issuedrange.first;
     auto q = m_issuedrange.first;
     set_error_at( (q == m_queries.end()) ?  thud + 1 : q->first);
-
-    pqxxassert(
-	m_num_waiting == std::distance(m_issuedrange.second, m_queries.end()));
   }
-
-  pqxxassert(m_issuedrange.first != m_queries.end());
-  pqxxassert(m_error <= m_q_id);
 }
 
 
@@ -366,18 +335,16 @@ std::pair<pipeline::query_id, result>
 pqxx::pipeline::retrieve(pipeline::QueryMap::iterator q)
 {
   if (q == m_queries.end())
-    throw std::logic_error("Attempt to retrieve result for unknown query");
+    throw std::logic_error{"Attempt to retrieve result for unknown query."};
 
   if (q->first >= m_error)
-    throw std::runtime_error(
-	"Could not complete query in pipeline due to error in earlier query");
+    throw std::runtime_error{
+	"Could not complete query in pipeline due to error in earlier query."};
 
   // If query hasn't issued yet, do it now
-  if (m_issuedrange.second != m_queries.end() &&
+  if (m_issuedrange.second != m_queries.end() and
       (q->first >= m_issuedrange.second->first))
   {
-    pqxxassert(std::distance(m_issuedrange.second, q) >= 0);
-
     if (have_pending()) receive(m_issuedrange.second);
     if (m_error == qid_limit()) issue();
   }
@@ -397,38 +364,35 @@ pqxx::pipeline::retrieve(pipeline::QueryMap::iterator q)
     }
   }
 
-  pqxxassert((m_error <= q->first) || (q != m_issuedrange.first));
-
   if (q->first >= m_error)
-    throw std::runtime_error(
-	"Could not complete query in pipeline due to error in earlier query");
+    throw std::runtime_error{
+	"Could not complete query in pipeline due to error in earlier query."};
 
   // Don't leave the backend idle if there are queries waiting to be issued
-  if (m_num_waiting && !have_pending() && (m_error==qid_limit())) issue();
+  if (m_num_waiting and not have_pending() and (m_error==qid_limit())) issue();
 
   const result R = q->second.get_result();
   const auto P = std::make_pair(q->first, R);
 
   m_queries.erase(q);
 
-  gate::result_creation(R).check_status();
+  gate::result_creation{R}.check_status();
   return P;
 }
 
 
 void pqxx::pipeline::get_further_available_results()
 {
-  pqxxassert(!m_dummy_pending);
-  gate::connection_pipeline gate(m_trans.conn());
-  while (!gate.is_busy() && obtain_result())
-    if (!gate.consume_input()) throw broken_connection();
+  gate::connection_pipeline gate{m_trans.conn()};
+  while (not gate.is_busy() and obtain_result())
+    if (not gate.consume_input()) throw broken_connection{};
 }
 
 
 void pqxx::pipeline::receive_if_available()
 {
-  gate::connection_pipeline gate(m_trans.conn());
-  if (!gate.consume_input()) throw broken_connection();
+  gate::connection_pipeline gate{m_trans.conn()};
+  if (not gate.consume_input()) throw broken_connection{};
   if (gate.is_busy()) return;
 
   if (m_dummy_pending) obtain_dummy();
@@ -438,14 +402,12 @@ void pqxx::pipeline::receive_if_available()
 
 void pqxx::pipeline::receive(pipeline::QueryMap::const_iterator stop)
 {
-  pqxxassert(have_pending());
-
   if (m_dummy_pending) obtain_dummy();
 
-  while (obtain_result() &&
-         QueryMap::const_iterator(m_issuedrange.first) != stop) ;
+  while (obtain_result() and
+         QueryMap::const_iterator{m_issuedrange.first} != stop) ;
 
   // Also haul in any remaining "targets of opportunity"
-  if (QueryMap::const_iterator(m_issuedrange.first) == stop)
+  if (QueryMap::const_iterator{m_issuedrange.first} == stop)
     get_further_available_results();
 }
