@@ -2,7 +2,7 @@
  *
  * See the connection_base hierarchy for more about prepared statements.
  *
- * Copyright (c) 2006-2017, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2019, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -25,8 +25,8 @@ using namespace pqxx::internal;
 pqxx::prepare::invocation::invocation(
 	transaction_base &home,
 	const std::string &statement) :
-  m_home(home),
-  m_statement(statement)
+  m_home{home},
+  m_statement{statement}
 {
 }
 
@@ -38,23 +38,23 @@ pqxx::result pqxx::prepare::invocation::exec() const
   std::vector<int> binaries;
   const int elts = marshall(ptrs, lens, binaries);
 
-  return gate::connection_prepare_invocation(m_home.conn()).prepared_exec(
+  return gate::connection_prepare_invocation{m_home.conn()}.prepared_exec(
 	m_statement,
-	&ptrs[0],
-	&lens[0],
-	&binaries[0],
+	ptrs.data(),
+	lens.data(),
+	binaries.data(),
 	elts);
 }
 
 
 bool pqxx::prepare::invocation::exists() const
 {
-  return gate::connection_prepare_invocation(m_home.conn()).prepared_exists(
+  return gate::connection_prepare_invocation{m_home.conn()}.prepared_exists(
 	m_statement);
 }
 
 
 pqxx::prepare::internal::prepared_def::prepared_def(const std::string &def) :
-  definition(def)
+  definition{def}
 {
 }
