@@ -2,7 +2,7 @@
  *
  * pqxx::result represents the set of result rows from a database query
  *
- * Copyright (c) 2001-2017, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2019, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -14,12 +14,18 @@
 #include <cstring>
 #include <stdexcept>
 
+extern "C"
+{
 #include "libpq-fe.h"
+}
 
 #include "pqxx/except"
 #include "pqxx/result"
 
 
+const std::string pqxx::result::s_empty_string;
+
+
 /// C++ wrapper for libpq's PQclear.
 void pqxx::internal::clear_result(const pq::PGresult *data)
 {
@@ -29,9 +35,11 @@ void pqxx::internal::clear_result(const pq::PGresult *data)
 
 pqxx::result::result(
 	pqxx::internal::pq::PGresult *rhs,
-	const std::string &Query) :
-  m_data(make_data_pointer(rhs)),
-  m_query(Query)
+	const std::string &Query,
+        internal::encoding_group enc) :
+  m_data{make_data_pointer(rhs)},
+  m_query{std::make_shared<std::string>(Query)},
+  m_encoding(enc)
 {
 }
 
@@ -49,7 +57,7 @@ bool pqxx::result::operator==(const result &rhs) const noexcept
 
 pqxx::result::const_reverse_iterator pqxx::result::rbegin() const
 {
-  return const_reverse_iterator(end());
+  return const_reverse_iterator{end()};
 }
 
 
@@ -61,7 +69,7 @@ pqxx::result::const_reverse_iterator pqxx::result::crbegin() const
 
 pqxx::result::const_reverse_iterator pqxx::result::rend() const
 {
-  return const_reverse_iterator(begin());
+  return const_reverse_iterator{begin()};
 }
 
 
@@ -73,7 +81,7 @@ pqxx::result::const_reverse_iterator pqxx::result::crend() const
 
 pqxx::result::const_iterator pqxx::result::begin() const noexcept
 {
-  return const_iterator(this, 0);
+  return const_iterator{this, 0};
 }
 
 
@@ -91,19 +99,19 @@ pqxx::result::size_type pqxx::result::size() const noexcept
 
 bool pqxx::result::empty() const noexcept
 {
-  return !m_data.get() || !PQntuples(m_data.get());
+  return (m_data.get() == nullptr) or (PQntuples(m_data.get()) == 0);
 }
 
 
 pqxx::result::reference pqxx::result::front() const noexcept
 {
-  return row(*this, 0);
+  return row{*this, 0};
 }
 
 
 pqxx::result::reference pqxx::result::back() const noexcept
 {
-  return row(*this, size() - 1);
+  return row{*this, size() - 1};
 }
 
 
@@ -116,17 +124,26 @@ void pqxx::result::swap(result &rhs) noexcept
 
 const pqxx::row pqxx::result::operator[](result_size_type i) const noexcept
 {
-  return row(*this, i);
+  return row{*this, i};
 }
 
 
 const pqxx::row pqxx::result::at(pqxx::result::size_type i) const
 {
-  if (i >= size()) throw range_error("Row number out of range");
+  if (i >= size()) throw range_error{"Row number out of range."};
   return operator[](i);
 }
 
 
+namespace
+{
+/// C string comparison.
+inline bool equal(const char lhs[], const char rhs[])
+{
+  return strcmp(lhs, rhs) == 0;
+}
+} // namespace
+
 void pqxx::result::ThrowSQLError(
 	const std::string &Err,
 	const std::string &Query) const
@@ -140,88 +157,88 @@ void pqxx::result::ThrowSQLError(
     switch (code[1])
     {
     case '8':
-      throw broken_connection(Err);
+      throw broken_connection{Err};
     case 'A':
-      throw feature_not_supported(Err, Query, code);
+      throw feature_not_supported{Err, Query, code};
     }
     break;
   case '2':
     switch (code[1])
     {
     case '2':
-      throw data_exception(Err, Query, code);
+      throw data_exception{Err, Query, code};
     case '3':
-      if (strcmp(code,"23001")==0) throw restrict_violation(Err, Query, code);
-      if (strcmp(code,"23502")==0) throw not_null_violation(Err, Query, code);
-      if (strcmp(code,"23503")==0)
-        throw foreign_key_violation(Err, Query, code);
-      if (strcmp(code,"23505")==0) throw unique_violation(Err, Query, code);
-      if (strcmp(code,"23514")==0) throw check_violation(Err, Query, code);
-      throw integrity_constraint_violation(Err, Query, code);
+      if (equal(code,"23001")) throw restrict_violation{Err, Query, code};
+      if (equal(code,"23502")) throw not_null_violation{Err, Query, code};
+      if (equal(code,"23503"))
+        throw foreign_key_violation{Err, Query, code};
+      if (equal(code,"23505")) throw unique_violation{Err, Query, code};
+      if (equal(code,"23514")) throw check_violation{Err, Query, code};
+      throw integrity_constraint_violation{Err, Query, code};
     case '4':
-      throw invalid_cursor_state(Err, Query, code);
+      throw invalid_cursor_state{Err, Query, code};
     case '6':
-      throw invalid_sql_statement_name(Err, Query, code);
+      throw invalid_sql_statement_name{Err, Query, code};
     }
     break;
   case '3':
     switch (code[1])
     {
     case '4':
-      throw invalid_cursor_name(Err, Query, code);
+      throw invalid_cursor_name{Err, Query, code};
     }
     break;
   case '4':
     switch (code[1])
     {
     case '0':
-      if (strcmp(code, "40000")==0) throw transaction_rollback(Err);
-      if (strcmp(code, "40001")==0) throw serialization_failure(Err);
-      if (strcmp(code, "40001")==0) throw statement_completion_unknown(Err);
-      if (strcmp(code, "40P01")==0) throw deadlock_detected(Err);
+      if (equal(code, "40000")) throw transaction_rollback{Err};
+      if (equal(code, "40001")) throw serialization_failure{Err};
+      if (equal(code, "40003")) throw statement_completion_unknown{Err};
+      if (equal(code, "40P01")) throw deadlock_detected{Err};
       break;
     case '2':
-      if (strcmp(code,"42501")==0) throw insufficient_privilege(Err, Query);
-      if (strcmp(code,"42601")==0)
-        throw syntax_error(Err, Query, code, errorposition());
-      if (strcmp(code,"42703")==0) throw undefined_column(Err, Query, code);
-      if (strcmp(code,"42883")==0) throw undefined_function(Err, Query, code);
-      if (strcmp(code,"42P01")==0) throw undefined_table(Err, Query, code);
+      if (equal(code,"42501")) throw insufficient_privilege{Err, Query};
+      if (equal(code,"42601"))
+        throw syntax_error{Err, Query, code, errorposition()};
+      if (equal(code,"42703")) throw undefined_column{Err, Query, code};
+      if (equal(code,"42883")) throw undefined_function{Err, Query, code};
+      if (equal(code,"42P01")) throw undefined_table{Err, Query, code};
     }
     break;
   case '5':
     switch (code[1])
     {
     case '3':
-      if (strcmp(code,"53100")==0) throw disk_full(Err, Query, code);
-      if (strcmp(code,"53200")==0) throw out_of_memory(Err, Query, code);
-      if (strcmp(code,"53300")==0) throw too_many_connections(Err);
-      throw insufficient_resources(Err, Query, code);
+      if (equal(code,"53100")) throw disk_full{Err, Query, code};
+      if (equal(code,"53200")) throw out_of_memory{Err, Query, code};
+      if (equal(code,"53300")) throw too_many_connections{Err};
+      throw insufficient_resources{Err, Query, code};
     }
     break;
 
   case 'P':
-    if (strcmp(code, "P0001")==0) throw plpgsql_raise(Err, Query, code);
-    if (strcmp(code, "P0002")==0)
-      throw plpgsql_no_data_found(Err, Query, code);
-    if (strcmp(code, "P0003")==0)
-      throw plpgsql_too_many_rows(Err, Query, code);
-    throw plpgsql_error(Err, Query, code);
+    if (equal(code, "P0001")) throw plpgsql_raise{Err, Query, code};
+    if (equal(code, "P0002"))
+      throw plpgsql_no_data_found{Err, Query, code};
+    if (equal(code, "P0003"))
+      throw plpgsql_too_many_rows{Err, Query, code};
+    throw plpgsql_error{Err, Query, code};
   }
   // Fallback: No error code.
-  throw sql_error(Err, Query, code);
+  throw sql_error{Err, Query, code};
 }
 
 void pqxx::result::check_status() const
 {
   const std::string Err = StatusError();
-  if (!Err.empty()) ThrowSQLError(Err, query());
+  if (not Err.empty()) ThrowSQLError(Err, query());
 }
 
 
 std::string pqxx::result::StatusError() const
 {
-  if (!m_data.get()) throw failure("No result set given");
+  if (m_data.get() == nullptr) throw failure{"No result set given."};
 
   std::string Err;
 
@@ -243,9 +260,9 @@ std::string pqxx::result::StatusError() const
     break;
 
   default:
-    throw internal_error(
+    throw internal_error{
 	"pqxx::result: Unrecognized response code " +
-	to_string(int(PQresultStatus(m_data.get()))));
+	to_string(int(PQresultStatus(m_data.get())))};
   }
   return Err;
 }
@@ -259,15 +276,15 @@ const char *pqxx::result::cmd_status() const noexcept
 
 const std::string &pqxx::result::query() const noexcept
 {
-  return m_query;
+  return m_query ? *m_query : s_empty_string;
 }
 
 
 pqxx::oid pqxx::result::inserted_oid() const
 {
-  if (!m_data.get())
-    throw usage_error(
-	"Attempt to read oid of inserted row without an INSERT result");
+  if (m_data.get() == nullptr)
+    throw usage_error{
+	"Attempt to read oid of inserted row without an INSERT result"};
   return PQoidValue(const_cast<internal::pq::PGresult *>(m_data.get()));
 }
 
@@ -307,9 +324,9 @@ pqxx::oid pqxx::result::column_type(row::size_type ColNum) const
 {
   const oid T = PQftype(m_data.get(), int(ColNum));
   if (T == oid_none)
-    throw argument_error(
+    throw argument_error{
 	"Attempt to retrieve type of nonexistent column " +
-	to_string(ColNum) + " of query result");
+	to_string(ColNum) + " of query result."};
   return T;
 }
 
@@ -321,10 +338,10 @@ pqxx::oid pqxx::result::column_table(row::size_type ColNum) const
   /* If we get oid_none, it may be because the column is computed, or because we
    * got an invalid row number.
    */
-  if (T == oid_none && ColNum >= columns())
-    throw argument_error(
+  if (T == oid_none and ColNum >= columns())
+    throw argument_error{
 	"Attempt to retrieve table ID for column " + to_string(ColNum) +
-	" out of " + to_string(columns()));
+	" out of " + to_string(columns())};
 
   return T;
 }
@@ -333,21 +350,21 @@ pqxx::oid pqxx::result::column_table(row::size_type ColNum) const
 pqxx::row::size_type pqxx::result::table_column(row::size_type ColNum) const
 {
   const auto n = row::size_type(PQftablecol(m_data.get(), int(ColNum)));
-  if (n) return n-1;
+  if (n != 0) return n-1;
 
   // Failed.  Now find out why, so we can throw a sensible exception.
   const std::string col_num = to_string(ColNum);
   if (ColNum > columns())
-    throw range_error("Invalid column index in table_column(): " + col_num);
+    throw range_error{"Invalid column index in table_column(): " + col_num};
 
-  if (!m_data.get())
-    throw usage_error(
+  if (m_data.get() == nullptr)
+    throw usage_error{
       "Can't query origin of column " + col_num + ": "
-      "result is not initialized.");
+      "result is not initialized."};
 
-  throw usage_error(
+  throw usage_error{
     "Can't query origin of column " + col_num + ": "
-    "not derived from table column");
+    "not derived from table column."};
 }
 
 int pqxx::result::errorposition() const
@@ -367,13 +384,13 @@ int pqxx::result::errorposition() const
 const char *pqxx::result::column_name(pqxx::row::size_type Number) const
 {
   const char *const N = PQfname(m_data.get(), int(Number));
-  if (!N)
+  if (N == nullptr)
   {
-    if (!m_data.get())
-      throw usage_error("Queried column name on null result.");
-    throw range_error(
+    if (m_data.get() == nullptr)
+      throw usage_error{"Queried column name on null result."};
+    throw range_error{
 	"Invalid column number: " + to_string(Number) +
-	" (maximum is " + to_string(columns() - 1) + ").");
+	" (maximum is " + to_string(columns() - 1) + ")."};
   }
   return N;
 }
@@ -390,7 +407,7 @@ pqxx::row::size_type pqxx::result::columns() const noexcept
 
 pqxx::const_result_iterator pqxx::const_result_iterator::operator++(int)
 {
-  const_result_iterator old(*this);
+  const_result_iterator old{*this};
   m_index++;
   return old;
 }
@@ -398,7 +415,7 @@ pqxx::const_result_iterator pqxx::const_result_iterator::operator++(int)
 
 pqxx::const_result_iterator pqxx::const_result_iterator::operator--(int)
 {
-  const_result_iterator old(*this);
+  const_result_iterator old{*this};
   m_index--;
   return old;
 }
@@ -407,7 +424,7 @@ pqxx::const_result_iterator pqxx::const_result_iterator::operator--(int)
 pqxx::result::const_iterator
 pqxx::result::const_reverse_iterator::base() const noexcept
 {
-  iterator_type tmp(*this);
+  iterator_type tmp{*this};
   return ++tmp;
 }
 
@@ -415,7 +432,7 @@ pqxx::result::const_reverse_iterator::base() const noexcept
 pqxx::const_reverse_result_iterator
 pqxx::const_reverse_result_iterator::operator++(int)
 {
-  const_reverse_result_iterator tmp(*this);
+  const_reverse_result_iterator tmp{*this};
   iterator_type::operator--();
   return tmp;
 }
@@ -424,7 +441,7 @@ pqxx::const_reverse_result_iterator::operator++(int)
 pqxx::const_reverse_result_iterator
 pqxx::const_reverse_result_iterator::operator--(int)
 {
-  const_reverse_result_iterator tmp(*this);
+  const_reverse_result_iterator tmp{*this};
   iterator_type::operator++();
   return tmp;
 }
@@ -433,5 +450,5 @@ pqxx::const_reverse_result_iterator::operator--(int)
 template<>
 std::string pqxx::to_string(const field &Obj)
 {
-  return std::string(Obj.c_str(), Obj.size());
+  return std::string{Obj.c_str(), Obj.size()};
 }
