@@ -2,7 +2,7 @@
  *
  * pqxx::transaction is a nested transaction, i.e. one within a transaction
  *
- * Copyright (c) 2005-2017, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2019, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -23,10 +23,10 @@ using namespace pqxx::internal;
 pqxx::subtransaction::subtransaction(
 	dbtransaction &T,
 	const std::string &Name) :
-  namedclass("subtransaction", T.conn().adorn_name(Name)),
-  transactionfocus(T),
+  namedclass{"subtransaction", T.conn().adorn_name(Name)},
+  transactionfocus{T},
   dbtransaction(T.conn(), false),
-  m_parent(T)
+  m_parent{T}
 {
 }
 
@@ -49,7 +49,7 @@ void pqxx::subtransaction::do_begin()
 {
   try
   {
-    direct_exec(("SAVEPOINT \"" + name() + "\"").c_str());
+    direct_exec(("SAVEPOINT " + quote_name(name())).c_str());
   }
   catch (const sql_error &)
   {
@@ -62,13 +62,13 @@ void pqxx::subtransaction::do_commit()
 {
   const int ra = m_reactivation_avoidance.get();
   m_reactivation_avoidance.clear();
-  direct_exec(("RELEASE SAVEPOINT \"" + name() + "\"").c_str());
-  gate::transaction_subtransaction(m_parent).add_reactivation_avoidance_count(
+  direct_exec(("RELEASE SAVEPOINT " + quote_name(name())).c_str());
+  gate::transaction_subtransaction{m_parent}.add_reactivation_avoidance_count(
 	ra);
 }
 
 
 void pqxx::subtransaction::do_abort()
 {
-  direct_exec(("ROLLBACK TO SAVEPOINT \"" + name() + "\"").c_str());
+  direct_exec(("ROLLBACK TO SAVEPOINT " + quote_name(name())).c_str());
 }
