@@ -2,7 +2,7 @@
  *
  * pqxx::tablestream provides optimized batch access to a database table.
  *
- * Copyright (c) 2001-2017, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2019, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -16,9 +16,9 @@
 
 pqxx::tablestream::tablestream(transaction_base &STrans,
 	const std::string &Null) :
-  internal::namedclass("tablestream"),
-  internal::transactionfocus(STrans),
-  m_null(Null)
+  internal::namedclass{"tablestream"},
+  internal::transactionfocus{STrans},
+  m_null{Null}
 {
 }
 
@@ -30,7 +30,7 @@ pqxx::tablestream::~tablestream() noexcept
 
 void pqxx::tablestream::base_close()
 {
-  if (!is_finished())
+  if (not is_finished())
   {
     m_finished = true;
     unregister_me();
