@@ -2,7 +2,7 @@
  *
  * pqxx::tablewriter enables optimized batch updates to a database table.
  *
- * Copyright (c) 2001-2017, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2019, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -23,10 +23,10 @@ pqxx::tablewriter::tablewriter(
 	transaction_base &T,
 	const std::string &WName,
 	const std::string &Null) :
-  namedclass("tablewriter", WName),
+  namedclass{"tablewriter", WName},
   tablestream(T, Null)
 {
-  setup(T, WName);
+  set_up(T, WName);
 }
 
 
@@ -43,12 +43,12 @@ pqxx::tablewriter::~tablewriter() noexcept
 }
 
 
-void pqxx::tablewriter::setup(
+void pqxx::tablewriter::set_up(
 	transaction_base &T,
 	const std::string &WName,
 	const std::string &Columns)
 {
-  gate::transaction_tablewriter(T).BeginCopyWrite(WName, Columns);
+  gate::transaction_tablewriter{T}.BeginCopyWrite(WName, Columns);
   register_me();
 }
 
@@ -65,10 +65,10 @@ pqxx::tablewriter &pqxx::tablewriter::operator<<(pqxx::tablereader &R)
 void pqxx::tablewriter::write_raw_line(const std::string &Line)
 {
   const std::string::size_type len = Line.size();
-  gate::transaction_tablewriter(m_trans).write_copy_line(
-	(!len || Line[len-1] != '\n') ?
+  gate::transaction_tablewriter{m_trans}.write_copy_line(
+	((len == 0) or (Line[len-1] != '\n')) ?
 	Line :
-        std::string(Line, 0, len-1));
+        std::string{Line, 0, len-1});
 }
 
 
@@ -80,12 +80,12 @@ void pqxx::tablewriter::complete()
 
 void pqxx::tablewriter::writer_close()
 {
-  if (!is_finished())
+  if (not is_finished())
   {
     base_close();
     try
     {
-      gate::transaction_tablewriter(m_trans).end_copy_write();
+      gate::transaction_tablewriter{m_trans}.end_copy_write();
     }
     catch (const std::exception &)
     {
@@ -116,7 +116,7 @@ inline char escapechar(char i) noexcept
 
 inline bool unprintable(char i) noexcept
 {
-  return i < ' ' || i > '~';
+  return i < ' ' or i > '~';
 }
 
 inline char tooctdigit(char c, int n)
