@@ -3,7 +3,7 @@
  * pqxx::transaction_base defines the interface for any abstract class that
  * represents a database transaction.
  *
- * Copyright (c) 2001-2017, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2019, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -22,6 +22,8 @@
 #include "pqxx/internal/gates/connection-parameterized_invocation.hxx"
 #include "pqxx/internal/gates/transaction-transactionfocus.hxx"
 
+#include "pqxx/internal/encodings.hxx"
+
 
 using namespace pqxx::internal;
 
@@ -29,8 +31,8 @@ using namespace pqxx::internal;
 pqxx::internal::parameterized_invocation::parameterized_invocation(
 	connection_base &c,
 	const std::string &query) :
-  m_home(c),
-  m_query(query)
+  m_home{c},
+  m_query{query}
 {
 }
 
@@ -42,22 +44,22 @@ pqxx::result pqxx::internal::parameterized_invocation::exec()
   std::vector<int> binaries;
   const int elements = marshall(values, lengths, binaries);
 
-  return gate::connection_parameterized_invocation(m_home).parameterized_exec(
+  return gate::connection_parameterized_invocation{m_home}.parameterized_exec(
 	m_query,
-	&values[0],
-	&lengths[0],
-	&binaries[0],
+	values.data(),
+	lengths.data(),
+	binaries.data(),
 	elements);
 }
 
 
 pqxx::transaction_base::transaction_base(connection_base &C, bool direct) :
-  namedclass("transaction_base"),
-  m_conn(C)
+  namedclass{"transaction_base"},
+  m_conn{C}
 {
   if (direct)
   {
-    gate::connection_transaction gate(conn());
+    gate::connection_transaction gate{conn()};
     gate.register_transaction(this);
     m_registered = true;
   }
@@ -69,13 +71,13 @@ pqxx::transaction_base::~transaction_base()
   try
   {
     reactivation_avoidance_clear();
-    if (!m_pending_error.empty())
+    if (not m_pending_error.empty())
       process_notice("UNPROCESSED ERROR: " + m_pending_error + "\n");
 
     if (m_registered)
     {
       m_conn.process_notice(description() + " was never closed properly!\n");
-      gate::connection_transaction gate(conn());
+      gate::connection_transaction gate{conn()};
       gate.unregister_transaction(this);
     }
   }
@@ -83,7 +85,7 @@ pqxx::transaction_base::~transaction_base()
   {
     try
     {
-      process_notice(std::string(e.what()) + "\n");
+      process_notice(std::string{e.what()} + "\n");
     }
     catch (const std::exception &)
     {
@@ -108,7 +110,7 @@ void pqxx::transaction_base::commit()
     break;
 
   case st_aborted:
-    throw usage_error("Attempt to commit previously aborted " + description());
+    throw usage_error{"Attempt to commit previously aborted " + description()};
 
   case st_committed:
     // Transaction has been committed already.  This is not exactly proper
@@ -116,17 +118,17 @@ void pqxx::transaction_base::commit()
     // that an abort is needed--which would only confuse things further at this
     // stage.
     // Therefore, multiple commits are accepted, though under protest.
-    m_conn.process_notice(description() + " committed more than once\n");
+    m_conn.process_notice(description() + " committed more than once.\n");
     return;
 
   case st_in_doubt:
     // Transaction may or may not have been committed.  The only thing we can
     // really do is keep telling the caller that the transaction is in doubt.
-    throw in_doubt_error(
-	description() + " committed again while in an indeterminate state");
+    throw in_doubt_error{
+	description() + " committed again while in an indeterminate state."};
 
   default:
-    throw internal_error("pqxx::transaction: invalid status code");
+    throw internal_error{"pqxx::transaction: invalid status code."};
   }
 
   // Tricky one.  If stream is nested in transaction but inside the same scope,
@@ -134,17 +136,17 @@ void pqxx::transaction_base::commit()
   // commit is premature.  Punish this swiftly and without fail to discourage
   // the habit from forming.
   if (m_focus.get())
-    throw failure(
+    throw failure{
 	"Attempt to commit " + description() + " with " +
-	m_focus.get()->description() + " still open");
+	m_focus.get()->description() + " still open."};
 
   // Check that we're still connected (as far as we know--this is not an
   // absolute thing!) before trying to commit.  If the connection was broken
   // already, the commit would fail anyway but this way at least we don't remain
   // in-doubt as to whether the backend got the commit order at all.
-  if (!m_conn.is_open())
-    throw broken_connection(
-	"Broken connection to backend; cannot complete transaction");
+  if (not m_conn.is_open())
+    throw broken_connection{
+	"Broken connection to backend; cannot complete transaction."};
 
   try
   {
@@ -162,7 +164,7 @@ void pqxx::transaction_base::commit()
     throw;
   }
 
-  gate::connection_transaction gate(conn());
+  gate::connection_transaction gate{conn()};
   gate.add_variables(m_vars);
 
   End();
@@ -186,7 +188,7 @@ void pqxx::transaction_base::abort()
     return;
 
   case st_committed:
-    throw usage_error("Attempt to abort previously committed " + description());
+    throw usage_error{"Attempt to abort previously committed " + description()};
 
   case st_in_doubt:
     // Aborting an in-doubt transaction is probably a reasonably sane response
@@ -197,7 +199,7 @@ void pqxx::transaction_base::abort()
     return;
 
   default:
-    throw internal_error("invalid transaction status");
+    throw internal_error{"Invalid transaction status."};
   }
 
   m_status = st_aborted;
@@ -234,12 +236,12 @@ void pqxx::transaction_base::activate()
   case st_committed:
   case st_aborted:
   case st_in_doubt:
-    throw usage_error(
+    throw usage_error{
 	"Attempt to activate " + description() + " "
-	"which is already closed");
+	"which is already closed."};
 
   default:
-    throw internal_error("pqxx::transaction: invalid status code");
+    throw internal_error{"pqxx::transaction: invalid status code."};
   }
 }
 
@@ -253,10 +255,10 @@ pqxx::result pqxx::transaction_base::exec(
   const std::string N = (Desc.empty() ? "" : "'" + Desc + "' ");
 
   if (m_focus.get())
-    throw usage_error(
+    throw usage_error{
 	"Attempt to execute query " + N +
 	"on " + description() + " "
-	"with " + m_focus.get()->description() + " still open");
+	"with " + m_focus.get()->description() + " still open."};
 
   try
   {
@@ -264,7 +266,7 @@ pqxx::result pqxx::transaction_base::exec(
   }
   catch (const usage_error &e)
   {
-    throw usage_error("Error executing query " + N + ".  " + e.what());
+    throw usage_error{"Error executing query " + N + ".  " + e.what()};
   }
 
   // TODO: Pass Desc to do_exec(), and from there on down
@@ -281,9 +283,9 @@ pqxx::result pqxx::transaction_base::exec_n(
   if (r.size() != rows)
   {
     const std::string N = (Desc.empty() ? "" : "'" + Desc + "'");
-    throw unexpected_rows(
+    throw unexpected_rows{
 	"Expected " + to_string(rows) + " row(s) of data "
-        "from query " + N + ", got " + to_string(r.size()) + ".");
+        "from query " + N + ", got " + to_string(r.size()) + "."};
   }
   return r;
 }
@@ -296,10 +298,10 @@ void pqxx::transaction_base::check_rowcount_prepared(
 {
   if (actual_rows != expected_rows)
   {
-    throw unexpected_rows(
+    throw unexpected_rows{
 	"Expected " + to_string(expected_rows) + " row(s) of data "
 	"from prepared statement '" + statement + "', got " +
-	to_string(actual_rows) + ".");
+	to_string(actual_rows) + "."};
   }
 }
 
@@ -310,9 +312,9 @@ void pqxx::transaction_base::check_rowcount_params(
 {
   if (actual_rows != expected_rows)
   {
-    throw unexpected_rows(
+    throw unexpected_rows{
 	"Expected " + to_string(expected_rows) + " row(s) of data "
-	"from parameterised query, got " + to_string(actual_rows) + ".");
+	"from parameterised query, got " + to_string(actual_rows) + "."};
   }
 }
 
@@ -320,7 +322,9 @@ void pqxx::transaction_base::check_rowcount_params(
 pqxx::internal::parameterized_invocation
 pqxx::transaction_base::parameterized(const std::string &query)
 {
-  return internal::parameterized_invocation(conn(), query);
+#include "pqxx/internal/ignore-deprecated-pre.hxx"
+  return internal::parameterized_invocation{conn(), query};
+#include "pqxx/internal/ignore-deprecated-post.hxx"
 }
 
 
@@ -333,10 +337,12 @@ pqxx::transaction_base::prepared(const std::string &statement)
   }
   catch (const usage_error &e)
   {
-    throw usage_error(
-	"Error executing prepared statement " + statement + ".  " + e.what());
+    throw usage_error{
+	"Error executing prepared statement " + statement + ".  " + e.what()};
   }
-  return prepare::invocation(*this, statement);
+#include "pqxx/internal/ignore-deprecated-pre.hxx"
+  return prepare::invocation{*this, statement};
+#include "pqxx/internal/ignore-deprecated-post.hxx"
 }
 
 
@@ -344,7 +350,7 @@ pqxx::result pqxx::transaction_base::internal_exec_prepared(
 	const std::string &statement,
 	const internal::params &args)
 {
-  gate::connection_transaction gate(conn());
+  gate::connection_transaction gate{conn()};
   return gate.exec_prepared(statement, args);
 }
 
@@ -353,7 +359,7 @@ pqxx::result pqxx::transaction_base::internal_exec_params(
 	const std::string &query,
 	const internal::params &args)
 {
-  gate::connection_transaction gate(conn());
+  gate::connection_transaction gate{conn()};
   return gate.exec_params(query, args);
 }
 
@@ -363,7 +369,7 @@ void pqxx::transaction_base::set_variable(
 	const std::string &Value)
 {
   // Before committing to this new value, see what the backend thinks about it
-  gate::connection_transaction gate(conn());
+  gate::connection_transaction gate{conn()};
   gate.raw_set_var(Var, Value);
   m_vars[Var] = Value;
 }
@@ -373,15 +379,15 @@ std::string pqxx::transaction_base::get_variable(const std::string &Var)
 {
   const std::map<std::string,std::string>::const_iterator i = m_vars.find(Var);
   if (i != m_vars.end()) return i->second;
-  return gate::connection_transaction(conn()).raw_get_var(Var);
+  return gate::connection_transaction{conn()}.raw_get_var(Var);
 }
 
 
 void pqxx::transaction_base::Begin()
 {
   if (m_status != st_nascent)
-    throw internal_error(
-	"pqxx::transaction: Begin() called while not in nascent state");
+    throw internal_error{
+	"pqxx::transaction: Begin() called while not in nascent state."};
 
   try
   {
@@ -406,10 +412,10 @@ void pqxx::transaction_base::End() noexcept
     try { CheckPendingError(); }
     catch (const std::exception &e) { m_conn.process_notice(e.what()); }
 
+    gate::connection_transaction gate{conn()};
     if (m_registered)
     {
       m_registered = false;
-      gate::connection_transaction gate(conn());
       gate.unregister_transaction(this);
     }
 
@@ -418,12 +424,11 @@ void pqxx::transaction_base::End() noexcept
     if (m_focus.get())
       m_conn.process_notice(
 	"Closing " + description() + "  with " +
-	m_focus.get()->description() + " still open\n");
+	m_focus.get()->description() + " still open.\n");
 
     try { abort(); }
     catch (const std::exception &e) { m_conn.process_notice(e.what()); }
 
-    gate::connection_transaction gate(conn());
     gate.take_reactivation_avoidance(m_reactivation_avoidance.get());
     m_reactivation_avoidance.clear();
   }
@@ -449,7 +454,7 @@ void pqxx::transaction_base::unregister_focus(internal::transactionfocus *S)
   }
   catch (const std::exception &e)
   {
-    m_conn.process_notice(std::string(e.what()) + "\n");
+    m_conn.process_notice(std::string{e.what()} + "\n");
   }
 }
 
@@ -457,14 +462,14 @@ void pqxx::transaction_base::unregister_focus(internal::transactionfocus *S)
 pqxx::result pqxx::transaction_base::direct_exec(const char C[], int Retries)
 {
   CheckPendingError();
-  return gate::connection_transaction(conn()).exec(C, Retries);
+  return gate::connection_transaction{conn()}.exec(C, Retries);
 }
 
 
 void pqxx::transaction_base::register_pending_error(const std::string &Err)
 	noexcept
 {
-  if (m_pending_error.empty() && !Err.empty())
+  if (m_pending_error.empty() and not Err.empty())
   {
     try
     {
@@ -489,11 +494,11 @@ void pqxx::transaction_base::register_pending_error(const std::string &Err)
 
 void pqxx::transaction_base::CheckPendingError()
 {
-  if (!m_pending_error.empty())
+  if (not m_pending_error.empty())
   {
-    const std::string Err(m_pending_error);
+    const std::string Err{m_pending_error};
     m_pending_error.clear();
-    throw failure(Err);
+    throw failure{Err};
   }
 }
 
@@ -505,7 +510,7 @@ std::string MakeCopyString(
         const std::string &Columns)
 {
   std::string Q = "COPY " + Table + " ";
-  if (!Columns.empty()) Q += "(" + Columns + ") ";
+  if (not Columns.empty()) Q += "(" + Columns + ") ";
   return Q;
 }
 } // namespace
@@ -529,27 +534,27 @@ void pqxx::transaction_base::BeginCopyWrite(
 
 bool pqxx::transaction_base::read_copy_line(std::string &line)
 {
-  return gate::connection_transaction(conn()).read_copy_line(line);
+  return gate::connection_transaction{conn()}.read_copy_line(line);
 }
 
 
 void pqxx::transaction_base::write_copy_line(const std::string &line)
 {
-  gate::connection_transaction gate(conn());
+  gate::connection_transaction gate{conn()};
   gate.write_copy_line(line);
 }
 
 
 void pqxx::transaction_base::end_copy_write()
 {
-  gate::connection_transaction gate(conn());
+  gate::connection_transaction gate{conn()};
   gate.end_copy_write();
 }
 
 
 void pqxx::internal::transactionfocus::register_me()
 {
-  gate::transaction_transactionfocus gate(m_trans);
+  gate::transaction_transactionfocus gate{m_trans};
   gate.register_focus(this);
   m_registered = true;
 }
@@ -557,7 +562,7 @@ void pqxx::internal::transactionfocus::register_me()
 
 void pqxx::internal::transactionfocus::unregister_me() noexcept
 {
-  gate::transaction_transactionfocus gate(m_trans);
+  gate::transaction_transactionfocus gate{m_trans};
   gate.unregister_focus(this);
   m_registered = false;
 }
@@ -566,6 +571,6 @@ void
 pqxx::internal::transactionfocus::reg_pending_error(const std::string &err)
 	noexcept
 {
-  gate::transaction_transactionfocus gate(m_trans);
+  gate::transaction_transactionfocus gate{m_trans};
   gate.register_pending_error(err);
 }
