@@ -1,6 +1,6 @@
 /** Various utility functions.
  *
- * Copyright (c) 2003-2017, Jeroen T. Vermeulen.
+ * Copyright (c) 2000-2019, Jeroen T. Vermeulen.
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -16,7 +16,10 @@
 #include <new>
 #include <thread>
 
+extern "C"
+{
 #include "libpq-fe.h"
+}
 
 #include "pqxx/except"
 #include "pqxx/util"
@@ -54,7 +57,7 @@ std::string pqxx::internal::namedclass::description() const
   try
   {
     std::string desc = classname();
-    if (!name().empty()) desc += " '" + name() + "'";
+    if (not name().empty()) desc += " '" + name() + "'";
     return desc;
   }
   catch (const std::exception &)
@@ -69,15 +72,15 @@ std::string pqxx::internal::namedclass::description() const
 void pqxx::internal::CheckUniqueRegistration(const namedclass *New,
     const namedclass *Old)
 {
-  if (!New)
-    throw internal_error("null pointer registered");
+  if (New == nullptr)
+    throw internal_error{"null pointer registered."};
   if (Old)
   {
     if (Old == New)
-      throw usage_error("Started twice: " + New->description());
-    throw usage_error(
+      throw usage_error{"Started twice: " + New->description()};
+    throw usage_error{
 	"Started " + New->description() + " while " + Old->description() +
-	" still active");
+	" still active."};
   }
 }
 
@@ -87,15 +90,15 @@ void pqxx::internal::CheckUniqueUnregistration(const namedclass *New,
 {
   if (New != Old)
   {
-    if (!New)
-      throw usage_error(
+    if (New == nullptr)
+      throw usage_error{
 	"Expected to close " + Old->description() + ", "
-	"but got null pointer instead");
-    if (!Old)
-      throw usage_error("Closed while not open: " + New->description());
-    throw usage_error(
+	"but got null pointer instead."};
+    if (Old == nullptr)
+      throw usage_error{"Closed while not open: " + New->description()};
+    throw usage_error{
 	"Closed " + New->description() + "; "
-	"expected to close " + Old->description());
+	"expected to close " + Old->description()};
   }
 }
 
