@@ -2,7 +2,6 @@
 
 #include "test_helpers.hxx"
 
-using namespace std;
 using namespace pqxx;
 
 
@@ -11,37 +10,38 @@ namespace
 
 // Simple test program for libpqxx.  Open connection to database, start
 // a transaction, and perform a query inside it.
-void test_001(transaction_base &trans)
+void test_001()
 {
-  cout << "Connected to database." << endl
-       << "Backend version: " << trans.conn().server_version() << endl
-       << "Protocol version: " << trans.conn().protocol_version() << endl;
-
-  // Close old transaction.
-  trans.abort();
+  connection conn;
+  std::cout
+	<< "Connected to database." << std::endl
+	<< "Backend version: " << conn.server_version() << std::endl
+	<< "Protocol version: " << conn.protocol_version() << std::endl;
 
   // Begin a transaction acting on our current connection.  Give it a human-
   // readable name so the library can include it in error messages.
-  work T(trans.conn(), "test1");
+  work tx{conn, "test1"};
 
   // Perform a query on the database, storing result rows in R.
-  result R( T.exec("SELECT * FROM pg_tables") );
+  result r( tx.exec("SELECT * FROM pg_tables") );
 
   // We're expecting to find some tables...
-  PQXX_CHECK(!R.empty(), "No tables found.  Cannot test.");
+  PQXX_CHECK(not r.empty(), "No tables found.  Cannot test.");
 
   // Process each successive result row
-  for (const auto &c: R)
+  for (const auto &c: r)
   {
     // Dump row number and column 0 value to cout.  Read the value using
     // as(), which converts the field to the same type as the default value
     // you give it (or returns the default value if the field is null).
-    cout << '\t' << to_string(c.num()) << '\t' << c[0].as(string()) << endl;
+    std::cout
+	<< '\t' << to_string(c.num()) << '\t' << c[0].as(std::string{})
+	<< std::endl;
   }
 
-  T.commit();
+  tx.commit();
 }
 
-} // namespace
 
-PQXX_REGISTER_TEST(test_001)
+PQXX_REGISTER_TEST(test_001);
+} // namespace
