@@ -4,7 +4,6 @@
 
 #include "test_helpers.hxx"
 
-using namespace std;
 using namespace pqxx;
 
 
@@ -16,14 +15,14 @@ namespace
 // Let's take a boring year that is not going to be in the "pqxxevents" table
 const int BoringYear = 1977;
 
-const string Table("pqxxevents");
+const std::string Table("pqxxevents");
 
 
 // Count events, and boring events, in table
-pair<int,int> CountEvents(transaction_base &T)
+std::pair<int,int> CountEvents(transaction_base &T)
 {
-  const string EventsQuery = "SELECT count(*) FROM " + Table;
-  const string BoringQuery =
+  const std::string EventsQuery = "SELECT count(*) FROM " + Table;
+  const std::string BoringQuery =
 	EventsQuery + " WHERE year=" + to_string(BoringYear);
   int EventsCount = 0,
       BoringCount = 0;
@@ -34,7 +33,7 @@ pair<int,int> CountEvents(transaction_base &T)
   R = T.exec1(BoringQuery);
   R.front().to(BoringCount);
 
-  return make_pair(EventsCount, BoringCount);
+  return std::make_pair(EventsCount, BoringCount);
 }
 
 
@@ -43,16 +42,14 @@ pair<int,int> CountEvents(transaction_base &T)
 // performed correctly.
 void Test(connection_base &C, bool ExplicitAbort)
 {
-  std::vector<std::string> BoringRow{to_string(BoringYear), "yawn"};
-
-  pair<int,int> EventCounts;
+  std::pair<int,int> EventCounts;
 
   // First run our doomed transaction.  This will refuse to run if an event
   // exists for our Boring Year.
   {
     // Begin a transaction acting on our current connection; we'll abort it
     // later though.
-    work Doomed(C, "Doomed");
+    work Doomed{C, "Doomed"};
 
     // Verify that our Boring Year was not yet in the events table
     EventCounts = CountEvents(Doomed);
@@ -63,18 +60,9 @@ void Test(connection_base &C, bool ExplicitAbort)
 	"Can't run, boring year is already in table.");
 
     // Now let's try to introduce a row for our Boring Year
-    {
-      tablewriter W(Doomed, Table);
-
-      PQXX_CHECK_EQUAL(W.name(), Table, "tablewriter's name changed.");
-
-      PQXX_CHECK_EQUAL(
-	W.generate(BoringRow),
-	separated_list("\t", BoringRow),
-	"tablewriter writes new row incorrectly.");
-
-      W.push_back(BoringRow);
-    }
+    Doomed.exec0(
+	"INSERT INTO " + Table + "(year, event) "
+        "VALUES (" + to_string(BoringYear) + ", 'yawn')");
 
     const auto Recount = CountEvents(Doomed);
     PQXX_CHECK_EQUAL(
@@ -114,15 +102,17 @@ void Test(connection_base &C, bool ExplicitAbort)
 }
 
 
-void test_abort(transaction_base &t)
+void test_abort()
 {
+  connection conn;
+  nontransaction t{conn};
   test::create_pqxxevents(t);
   connection_base &c(t.conn());
   t.commit();
   Test(c, true);
   Test(c, false);
 }
+
+
+PQXX_REGISTER_TEST(test_abort);
 } // namespace
-
-
-PQXX_REGISTER_TEST_T(test_abort, nontransaction)
