@@ -2,25 +2,25 @@
 
 #include "test_helpers.hxx"
 
-using namespace std;
 using namespace pqxx;
 
 
-// Simple test program for libpqxx.  Open connection to database, start
-// a dummy transaction to gain nontransactional access, and perform a query.
+// Test robusttransaction.
 namespace
 {
-void test_016(transaction_base &T)
+void test_016()
 {
-  result R( T.exec("SELECT * FROM pg_tables") );
+  connection conn;
+  robusttransaction<> tx{conn};
+  result R{ tx.exec("SELECT * FROM pg_tables") };
 
   result::const_iterator c;
   for (c = R.begin(); c != R.end(); ++c)
   {
-    string N;
+    std::string N;
     c[0].to(N);
 
-    cout << '\t' << to_string(c.num()) << '\t' << N << endl;
+    std::cout << '\t' << to_string(c.num()) << '\t' << N << std::endl;
   }
 
   // See if back() and row comparison work properly
@@ -33,19 +33,18 @@ void test_016(transaction_base &T)
 	R.back().size(),
 	"Size mismatch between row iterator and back().");
 
-  const string nullstr;
+  const std::string nullstr;
   for (pqxx::row::size_type i = 0; i < c->size(); ++i)
     PQXX_CHECK_EQUAL(
 	c[i].as(nullstr),
 	R.back()[i].as(nullstr),
 	"Value mismatch in back().");
     PQXX_CHECK(c == R.back(), "Row equality is broken.");
-    PQXX_CHECK(!(c != R.back()), "Row inequality is broken.");
+    PQXX_CHECK(not (c != R.back()), "Row inequality is broken.");
 
-  // "Commit" the non-transaction.  This doesn't really do anything since
-  // NonTransaction doesn't start a backend transaction.
-  T.commit();
+  tx.commit();
 }
-} // namespace
 
-PQXX_REGISTER_TEST_T(test_016, robusttransaction<>)
+
+PQXX_REGISTER_TEST(test_016);
+} // namespace
