@@ -4,7 +4,6 @@
 
 #include "test_helpers.hxx"
 
-using namespace std;
 using namespace pqxx;
 
 
@@ -22,7 +21,7 @@ public:
   explicit TestListener(connection_base &C) :
 	notification_receiver(C, "listen"), m_done(false) {}
 
-  virtual void operator()(const string &, int be_pid) override
+  virtual void operator()(const std::string &, int be_pid) override
   {
     m_done = true;
     PQXX_CHECK_EQUAL(
@@ -30,64 +29,39 @@ public:
 	conn().backendpid(),
 	"Notification came from wrong backend process.");
 
-    cout << "Received notification: " << channel() << " pid=" << be_pid << endl;
+    std::cout
+	<< "Received notification: " << channel() << " pid=" << be_pid
+	<< std::endl;
   }
 
   bool done() const { return m_done; }
 };
 
 
-// A transactor to trigger our notification listener
-class Notify : public transactor<>
-{
-  string m_channel;
-
-public:
-  explicit Notify(string NotifName) :
-    transactor<>("Notifier"), m_channel(NotifName) { }
-
-  void operator()(argument_type &T)
-  {
-    T.exec("NOTIFY " + m_channel);
-  }
-
-  void on_abort(const char Reason[]) noexcept
-  {
-    try
-    {
-      cerr << "Notify failed!" << endl;
-      if (Reason) cerr << "Reason: " << Reason << endl;
-    }
-    catch (const exception &)
-    {
-    }
-  }
-};
-
-
-void test_023(transaction_base &)
+void test_023()
 {
   lazyconnection C;
-  cout << "Adding listener..." << endl;
-  TestListener L(C);
+  std::cout << "Adding listener..." << std::endl;
+  TestListener L{C};
 
-  cout << "Sending notification..." << endl;
-  C.perform(Notify(L.channel()));
+  std::cout << "Sending notification..." << std::endl;
+  perform([&C, &L](){ nontransaction{C}.exec("NOTIFY " + L.channel()); });
 
   int notifs = 0;
-  for (int i=0; (i < 20) && !L.done(); ++i)
+  for (int i=0; (i < 20) and not L.done(); ++i)
   {
     PQXX_CHECK_EQUAL(notifs, 0, "Got unexpected notifications.");
     pqxx::internal::sleep_seconds(1);
     notifs = C.get_notifs();
-    cout << ".";
+    std::cout << ".";
   }
-  cout << endl;
+  std::cout << std::endl;
 
   PQXX_CHECK(L.done(), "No notification received.");
 
   PQXX_CHECK_EQUAL(notifs, 1, "Unexpected number of notifications.");
 }
-} // namespace
 
-PQXX_REGISTER_TEST_NODB(test_023)
+
+PQXX_REGISTER_TEST(test_023);
+} // namespace
