@@ -4,7 +4,6 @@
 
 #include "test_helpers.hxx"
 
-using namespace std;
 using namespace pqxx;
 
 
@@ -12,21 +11,21 @@ using namespace pqxx;
 // connection.
 namespace
 {
-void test_030(transaction_base &)
+void test_030()
 {
-  const string Table = "pg_tables";
+  const std::string Table = "pg_tables";
 
-  lazyconnection C;
-  work T(C, "test30");
+  lazyconnection conn;
+  work tx{conn, "test30"};
 
-  result R( T.exec(("SELECT * FROM " + Table).c_str()) );
-  PQXX_CHECK(!R.empty(), "Table " + Table + " is empty, cannot test.");
+  result R( tx.exec(("SELECT * FROM " + Table).c_str()) );
+  PQXX_CHECK(not R.empty(), "Table " + Table + " is empty, cannot test.");
 
   // Print column names
   for (pqxx::row::size_type c = 0; c < R.columns(); ++c)
   {
-    string N= R.column_name(c);
-    cout << c << ":\t" << N << endl;
+    std::string N = R.column_name(c);
+    std::cout << c << ":\t" << N << std::endl;
 
     PQXX_CHECK_EQUAL(
 	R[0].column_number(N),
@@ -42,28 +41,28 @@ void test_030(transaction_base &)
   // If there are rows in R, compare their metadata to R's.
   if (R.empty())
   {
-    cout << "(Table is empty.)" << endl;
+    std::cout << "(Table is empty.)" << std::endl;
     return;
   }
 
   PQXX_CHECK_EQUAL(R[0].rownumber(), 0u, "Row 0 reports wrong number.");
 
   if (R.size() < 2)
-    cout << "(Only one row in table.)" << endl;
+    std::cout << "(Only one row in table.)" << std::endl;
   else
     PQXX_CHECK_EQUAL(R[1].rownumber(), 1u, "Row 1 reports wrong number.");
 
   for (pqxx::row::size_type c = 0; c < R[0].size(); ++c)
   {
-    string N = R.column_name(c);
+    std::string N = R.column_name(c);
 
     PQXX_CHECK_EQUAL(
-	string(R[0].at(c).c_str()),
+	std::string{R[0].at(c).c_str()},
 	R[0].at(N).c_str(),
 	"Different field values by name and by number.");
 
     PQXX_CHECK_EQUAL(
-	string(R[0][c].c_str()),
+	std::string{R[0][c].c_str()},
 	R[0][N].c_str(),
 	"at() is inconsistent with operator[].");
 
@@ -74,10 +73,11 @@ void test_030(transaction_base &)
 
     PQXX_CHECK_EQUAL(
 	R[0][c].size(),
-	strlen(R[0][c].c_str()),
+	std::strlen(R[0][c].c_str()),
 	"Inconsistent field lengths.");
   }
 }
-} // namespace
 
-PQXX_REGISTER_TEST_NODB(test_030)
+
+PQXX_REGISTER_TEST(test_030);
+} // namespace
