@@ -2,7 +2,6 @@
 
 #include "test_helpers.hxx"
 
-using namespace std;
 using namespace pqxx;
 
 
@@ -10,22 +9,25 @@ using namespace pqxx;
 // a dummy transaction to gain nontransactional access, and perform a query.
 namespace
 {
-void test_033(transaction_base &T)
+void test_033()
 {
-  result R( T.exec("SELECT * FROM pg_tables") );
+  lazyconnection conn;
+  nontransaction tx{conn};
+  result R( tx.exec("SELECT * FROM pg_tables") );
 
   for (const auto &c: R)
   {
-    string N;
+    std::string N;
     c[0].to(N);
 
-    cout << '\t' << to_string(c.num()) << '\t' << N << endl;
+    std::cout << '\t' << to_string(c.num()) << '\t' << N << std::endl;
   }
 
   // "Commit" the non-transaction.  This doesn't really do anything since
   // nontransaction doesn't start a backend transaction.
-  T.commit();
+  tx.commit();
 }
-} // namespace
 
-PQXX_REGISTER_TEST_CT(test_033, lazyconnection, nontransaction)
+
+PQXX_REGISTER_TEST(test_033);
+} // namespace
