@@ -1,27 +1,25 @@
 #include "test_helpers.hxx"
 
-using namespace std;
 using namespace pqxx;
 
 
-// Test program for libpqxx.  Modify the database inside a NonTransaction, and
-// verify that the change gets made regardless of whether the NonTransaction is
-// eventually committed or aborted.  A lazy connection is used.
+// Test: nontransaction changes are committed immediately (tested here against
+// a lazyconnection).
 namespace
 {
 int BoringYear = 1977;
 
 
-void test_039(transaction_base &T1)
+void test_039()
 {
-  test::create_pqxxevents(T1);
-  connection_base &C(T1.conn());
-  const string Table = "pqxxevents";
-
+  lazyconnection conn;
+  nontransaction tx1{conn};
+  test::create_pqxxevents(tx1);
+  const std::string Table = "pqxxevents";
 
   // Verify our start condition before beginning: there must not be a 1977
   // record already.
-  result R( T1.exec("SELECT * FROM " + Table + " "
+  result R( tx1.exec("SELECT * FROM " + Table + " "
 	              "WHERE year=" + to_string(BoringYear)) );
 
   PQXX_CHECK_EQUAL(
@@ -34,21 +32,21 @@ void test_039(transaction_base &T1)
   PQXX_CHECK(R.empty(), "Result is non-empty after clear().");
 
   // OK.  Having laid that worry to rest, add a record for 1977.
-  T1.exec0(
+  tx1.exec0(
 	"INSERT INTO " + Table + " VALUES"
         "(" +
 	to_string(BoringYear) + ","
 	"'Yawn'"
 	")");
 
-  // Abort T1.  Since T1 is a NonTransaction, which provides only the
+  // Abort tx1.  Since tx1 is a nontransaction, which provides only the
   // transaction class interface without providing any form of transactional
   // integrity, this is not going to undo our work.
-  T1.abort();
+  tx1.abort();
 
   // Verify that our record was added, despite the Abort()
-  nontransaction T2(C, "T2");
-  R = T2.exec("SELECT * FROM " + Table + " "
+  nontransaction tx2(conn, "tx2");
+  R = tx2.exec("SELECT * FROM " + Table + " "
 		"WHERE year=" + to_string(BoringYear));
   PQXX_CHECK_EQUAL(R.size(), 1u, "Unexpected result size.");
 
@@ -58,19 +56,20 @@ void test_039(transaction_base &T1)
   PQXX_CHECK(R.empty(), "result::clear() is broken.");
 
   // Now remove our record again
-  T2.exec0("DELETE FROM " + Table + " "
+  tx2.exec0("DELETE FROM " + Table + " "
 	    "WHERE year=" + to_string(BoringYear));
 
-  T2.commit();
+  tx2.commit();
 
   // And again, verify results
-  nontransaction T3(C, "T3");
+  nontransaction tx3(conn, "tx3");
 
-  R = T3.exec("SELECT * FROM " + Table + " "
+  R = tx3.exec("SELECT * FROM " + Table + " "
 	        "WHERE year=" + to_string(BoringYear));
 
   PQXX_CHECK_EQUAL(R.size(), 0u, "Record is not gone as expected.");
 }
-} // namespace
 
-PQXX_REGISTER_TEST_CT(test_039, lazyconnection, nontransaction)
+
+PQXX_REGISTER_TEST(test_039);
+} // namespace
