@@ -1,21 +1,23 @@
 #include "test_helpers.hxx"
 
-using namespace std;
 using namespace pqxx;
 
 
 // Simple test program for libpqxx.  Issue invalid query and handle error.
 namespace
 {
-void test_056(transaction_base &T)
+void test_056()
 {
-  quiet_errorhandler d(T.conn());
+  connection conn;
+  work tx{conn};
+  quiet_errorhandler d(conn);
 
   PQXX_CHECK_THROWS(
-	T.exec("DELIBERATELY INVALID TEST QUERY...", "invalid_query"),
+	tx.exec("DELIBERATELY INVALID TEST QUERY...", "invalid_query"),
 	sql_error,
 	"SQL syntax error did not raise expected exception.");
 }
-} // namespace
 
-PQXX_REGISTER_TEST(test_056)
+
+PQXX_REGISTER_TEST(test_056);
+} // namespace
