@@ -1,6 +1,5 @@
 #include "../test_helpers.hxx"
 
-using namespace std;
 using namespace pqxx;
 
 
@@ -430,7 +429,7 @@ void test_nested_array_with_multiple_entries()
 }
 
 
-void test_array_parse(transaction_base &)
+void test_array_parse()
 {
   test_empty_arrays();
   test_null_value();
@@ -443,6 +442,7 @@ void test_array_parse(transaction_base &)
   test_nested_array();
   test_nested_array_with_multiple_entries();
 }
-} // namespace
 
-PQXX_REGISTER_TEST_NODB(test_array_parse)
+
+PQXX_REGISTER_TEST(test_array_parse);
+} // namespace
