@@ -5,7 +5,6 @@
 
 #include "../test_helpers.hxx"
 
-using namespace std;
 using namespace pqxx;
 
 
@@ -19,13 +18,13 @@ using namespace pqxx;
 
 namespace
 {
-string stringize(transaction_base &t, const string &arg)
+std::string stringize(transaction_base &t, const std::string &arg)
 {
   return "'" + t.esc(arg) + "'";
 }
 
 
-template<typename T> string stringize(transaction_base &t, T i)
+template<typename T> std::string stringize(transaction_base &t, T i)
 {
   return stringize(t, to_string(i));
 }
@@ -36,8 +35,9 @@ template<typename T> string stringize(transaction_base &t, T i)
 // and not knowing when to quote the variables.
 // Note we do the replacement backwards (meaning forward_only iterators won't
 // do!) to avoid substituting e.g. "$12" as "$1" first.
-template<typename ITER> string subst(transaction_base &t,
-	string q,
+template<typename ITER> std::string subst(
+	transaction_base &t,
+	std::string q,
 	ITER patbegin,
 	ITER patend)
 {
@@ -45,139 +45,150 @@ template<typename ITER> string subst(transaction_base &t,
   for (ITER arg = patend; i > 0; --i)
   {
    --arg;
-    const string marker = "$" + to_string(i),
+    const std::string marker = "$" + to_string(i),
 	  var = stringize(t, *arg);
-    const string::size_type msz = marker.size();
-    while (q.find(marker) != string::npos) q.replace(q.find(marker),msz,var);
+    const std::string::size_type msz = marker.size();
+    while (q.find(marker) != std::string::npos)
+	q.replace(q.find(marker),msz,var);
   }
   return q;
 }
 
 
-template<typename CNTNR> string subst(
+template<typename CNTNR> std::string subst(
 	transaction_base &t,
-	string q,
+	std::string q,
 	const CNTNR &patterns)
 {
   return subst(t, q, patterns.begin(), patterns.end());
 }
 
 
+#include <pqxx/internal/ignore-deprecated-pre.hxx>
+
+
 /// @deprecated To be replaced with the C++11-style exec_prepared.
-void test_legacy_prepared_statement(transaction_base &T)
+void test_legacy_prepared_statement()
 {
-  connection_base &C(T.conn());
+  connection conn;
+  work tx{conn};
 
   PQXX_CHECK(
-	!(T.prepared("CountToTen").exists()),
+	not tx.prepared("CountToTen").exists(),
 	"Nonexistent prepared statement thinks it exists.");
 
   // Prepare a simple statement.
-  C.prepare("CountToTen", "SELECT * FROM generate_series(1, 10)");
+  conn.prepare("CountToTen", "SELECT * FROM generate_series(1, 10)");
 
   PQXX_CHECK(
-	T.prepared("CountToTen").exists(),
+	tx.prepared("CountToTen").exists(),
 	"Prepared statement thinks it doesn't exist.");
 
   // See if a basic prepared statement works just like a regular query.
   PQXX_CHECK_EQUAL(
-	T.prepared("CountToTen").exec(),
-	T.exec("SELECT * FROM generate_series(1, 10)"),
+	tx.prepared("CountToTen").exec(),
+	tx.exec("SELECT * FROM generate_series(1, 10)"),
 	"CountToTen");
 
   // Try prepare_now() on an already prepared statement.
-  C.prepare_now("CountToTen");
+  conn.prepare_now("CountToTen");
 
   // Drop prepared statement.
-  C.unprepare("CountToTen");
+  conn.unprepare("CountToTen");
 
   PQXX_CHECK_THROWS_EXCEPTION(
-	C.prepare_now("CountToTen"),
+	conn.prepare_now("CountToTen"),
 	"prepare_now() succeeded on dropped statement.");
 
   // It's okay to unprepare a statement repeatedly.
-  C.unprepare("CountToTen");
-  C.unprepare("CountToTen");
+  conn.unprepare("CountToTen");
+  conn.unprepare("CountToTen");
 
   // Executing an unprepared statement fails.
   PQXX_CHECK_THROWS_EXCEPTION(
-	T.prepared("CountToTen").exec(),
+	tx.prepared("CountToTen").exec(),
 	"Execute unprepared statement didn't fail.");
 
   // Once unprepared, a statement can be prepared and used again.
-  C.prepare("CountToTen", "SELECT generate_series FROM generate_series(1, 10)");
-  C.prepare_now("CountToTen");
+  conn.prepare(
+	"CountToTen",
+	"SELECT generate_series FROM generate_series(1, 10)");
+  conn.prepare_now("CountToTen");
   COMPARE_RESULTS("CountToTen_2",
-	T.prepared("CountToTen").exec(),
-	T.exec("SELECT * FROM generate_series(1, 10)"));
+	tx.prepared("CountToTen").exec(),
+	tx.exec("SELECT * FROM generate_series(1, 10)"));
 
   // Double preparation of identical statement should be ignored...
-  C.prepare("CountToTen", "SELECT generate_series FROM generate_series(1, 10)");
+  conn.prepare(
+	"CountToTen",
+	"SELECT generate_series FROM generate_series(1, 10)");
   COMPARE_RESULTS("CountToTen_double",
-	T.prepared("CountToTen").exec(),
-	T.exec("SELECT * FROM generate_series(1, 10)"));
+	tx.prepared("CountToTen").exec(),
+	tx.exec("SELECT * FROM generate_series(1, 10)"));
 
   // ...But a modified definition shouldn't.
   PQXX_CHECK_THROWS_EXCEPTION(
-	C.prepare(
+	conn.prepare(
 		"CountToTen",
 		"SELECT generate_series FROM generate_series(1, 11)"),
 	"Bad redefinition of statement went unnoticed.");
 
   // Test prepared statement with parameter.
 
-  C.prepare("CountUpToTen", "SELECT * FROM generate_series($1, 10)");
+  conn.prepare("CountUpToTen", "SELECT * FROM generate_series($1, 10)");
 
-  vector<int> args = {2};
+  std::vector<int> args = {2};
   COMPARE_RESULTS("CountUpToTen_seq",
-	T.prepared("CountUpToTen")(args[0]).exec(),
-	T.exec(subst(T, "SELECT * FROM generate_series($1, 10)", args)));
+	tx.prepared("CountUpToTen")(args[0]).exec(),
+	tx.exec(subst(tx, "SELECT * FROM generate_series($1, 10)", args)));
 
   // Test prepared statement with 2 parameters.
 
-  C.prepare("CountRange", "SELECT * FROM generate_series($1::int, $2::int)");
+  conn.prepare(
+	"CountRange",
+	"SELECT * FROM generate_series($1::int, $2::int)");
   COMPARE_RESULTS("CountRange_seq",
-      T.prepared("CountRange")(2)(5).exec(),
-      T.exec("SELECT * FROM generate_series(2, 5)"));
+      tx.prepared("CountRange")(2)(5).exec(),
+      tx.exec("SELECT * FROM generate_series(2, 5)"));
 
   // Test prepared statement with a null parameter.
-  vector<const char *> ptrs = {nullptr, "99"};
+  std::vector<const char *> ptrs = {nullptr, "99"};
 
   COMPARE_RESULTS("CountRange_null1",
-	T.prepared("CountRange")(ptrs[0])(ptrs[1]).exec(),
-	T.exec("SELECT * FROM generate_series(NULL, 99)"));
+	tx.prepared("CountRange")(ptrs[0])(ptrs[1]).exec(),
+	tx.exec("SELECT * FROM generate_series(NULL, 99)"));
 
   // Test prepared statement with a binary parameter.
-  C.prepare("GimmeBinary", "SELECT $1::bytea");
+  conn.prepare("GimmeBinary", "SELECT $1::bytea");
 
-  const binarystring bin_data(string("x \x01 \x02 \xff y"));
+  const binarystring bin_data{std::string{"x \x01 \x02 \xff y"}};
 
   PQXX_CHECK_EQUAL(
-	binarystring(T.prepared("GimmeBinary")(bin_data).exec()[0][0]).str(),
+	binarystring(tx.prepared("GimmeBinary")(bin_data).exec()[0][0]).str(),
 	bin_data.str(),
 	"Binary parameter was mangled somewhere along the way.");
 
   const binarystring nully("x\0y", 3);
   PQXX_CHECK_EQUAL(
-	binarystring(T.prepared("GimmeBinary")(nully).exec()[0][0]).str(),
+	binarystring(tx.prepared("GimmeBinary")(nully).exec()[0][0]).str(),
 	nully.str(),
 	"Binary string breaks on nul byte.");
 
   // Test unnamed prepared statement.
-  C.prepare("SELECT 2*$1");
-  int outcome = T.prepared()(9).exec()[0][0].as<int>();
+  conn.prepare("SELECT 2*$1");
+  int outcome = tx.prepared()(9).exec()[0][0].as<int>();
   PQXX_CHECK_EQUAL(outcome, 18, "Unnamed prepared statement went mad.");
 
   // Redefine unnamed prepared statement.  Does not need to be unprepared
   // first.
-  C.prepare("SELECT 2*$1 + $2");
-  outcome = T.prepared()(9)(2).exec()[0][0].as<int>();
+  conn.prepare("SELECT 2*$1 + $2");
+  outcome = tx.prepared()(9)(2).exec()[0][0].as<int>();
   PQXX_CHECK_EQUAL(outcome, 20, "Unnamed statement not properly redefined.");
 
   // Unlike how the unnamed prepared statement works in libpq, we can issue
   // other queries and then re-use the unnamed prepared statement.
-  T.exec("SELECT 12");
-  outcome = T.prepared()(3)(1).exec()[0][0].as<int>();
+  tx.exec("SELECT 12");
+  outcome = tx.prepared()(3)(1).exec()[0][0].as<int>();
   PQXX_CHECK_EQUAL(outcome, 7, "Unnamed statement isn't what it was.");
 }
 
@@ -186,7 +197,7 @@ void test_registration_and_invocation(transaction_base &T)
 {
   constexpr auto count_to_5 = "SELECT * FROM generate_series(1, 5)";
   PQXX_CHECK(
-	!T.prepared("CountToFive").exists(),
+	not T.prepared("CountToFive").exists(),
 	"Nonexistent prepared statement thinks it exists.");
 
   // Prepare a simple statement.
@@ -280,26 +291,26 @@ void test_strings(transaction_base &T)
 {
   T.conn().prepare("EchoStr", "SELECT $1::varchar");
   auto rw = T.exec_prepared1("EchoStr", "foo");
-  PQXX_CHECK_EQUAL(rw.front().as<string>(), "foo", "Wrong string result.");
+  PQXX_CHECK_EQUAL(rw.front().as<std::string>(), "foo", "Wrong string result.");
 
   const char nasty_string[] = "'\\\"\\";
   rw = T.exec_prepared1("EchoStr", nasty_string);
   PQXX_CHECK_EQUAL(
-	rw.front().as<string>(),
-	string(nasty_string),
+	rw.front().as<std::string>(),
+	std::string(nasty_string),
 	"Prepared statement did not quote/escape correctly.");
 
-  rw = T.exec_prepared1("EchoStr", string(nasty_string));
+  rw = T.exec_prepared1("EchoStr", std::string{nasty_string});
   PQXX_CHECK_EQUAL(
-	rw.front().as<string>(),
-	string(nasty_string),
+	rw.front().as<std::string>(),
+	std::string(nasty_string),
 	"Quoting/escaping went wrong in std::string.");
 
   char nonconst[] = "non-const C string";
   rw = T.exec_prepared1("EchoStr", nonconst);
   PQXX_CHECK_EQUAL(
-	rw.front().as<string>(),
-	string(nonconst),
+	rw.front().as<std::string>(),
+	std::string(nonconst),
 	"Non-const C string passed incorrectly.");
 }
 
@@ -339,47 +350,59 @@ void test_dynamic_params(transaction_base &T)
 }
 
 
-/// Test against std::optional<int>, or std::experimental::optional<int>.
+/// Test against any optional type, such as std::optional<int> or 
+/// std::experimental::optional<int>.
 template<typename Opt>
 void test_optional(transaction_base &T)
 {
   T.conn().prepare("EchoNum", "SELECT $1::int");
-  pqxx::row rw = T.exec_prepared1("EchoNum", Opt(10));
+  pqxx::row rw = T.exec_prepared1(
+    "EchoNum",
+    pqxx::internal::make_optional<Opt>(10)
+  );
   PQXX_CHECK_EQUAL(
 	rw.front().as<int>(),
 	10,
-	"C++17 'optional' (with value) did not return the right value.");
+	"optional (with value) did not return the right value.");
 
   rw = T.exec_prepared1("EchoNum", Opt());
   PQXX_CHECK(
 	rw.front().is_null(),
-	"C++17 'optional' without value did not come out as null.");
+	"optional without value did not come out as null.");
 }
 
 
-void test_prepared_statements(transaction_base &T)
+void test_prepared_statements()
 {
-  test_registration_and_invocation(T);
-  test_basic_args(T);
-  test_multiple_params(T);
-  test_nulls(T);
-  test_strings(T);
-  test_binary(T);
-  test_dynamic_params(T);
+  connection conn;
+  work tx{conn};
+  test_registration_and_invocation(tx);
+  test_basic_args(tx);
+  test_multiple_params(tx);
+  test_nulls(tx);
+  test_strings(tx);
+  test_binary(tx);
+  test_dynamic_params(tx);
 
 #if defined(PQXX_HAVE_OPTIONAL)
-  test_optional<std::optional<int>>(T);
+  test_optional<std::optional<int>>(tx);
 #elif defined(PQXX_HAVE_EXP_OPTIONAL) && !defined(PQXX_HIDE_EXP_OPTIONAL)
-  test_optional<std::experimental::optional<int>>(T);
+  test_optional<std::experimental::optional<int>>(tx);
 #endif
+  test_optional<std::unique_ptr<int>>(tx);
+  test_optional<std::shared_ptr<int>>(tx);
 }
 
 
-void test_prepared_statement(transaction_base &T)
+#include <pqxx/internal/ignore-deprecated-post.hxx>
+
+
+void test_prepared_statement()
 {
-  test_legacy_prepared_statement(T);
-  test_prepared_statements(T);
+  test_legacy_prepared_statement();
+  test_prepared_statements();
 }
-} // namespace
 
-PQXX_REGISTER_TEST(test_prepared_statement)
+
+PQXX_REGISTER_TEST(test_prepared_statement);
+} // namespace
