@@ -2,9 +2,11 @@
 
 namespace
 {
-void test_result_iteration(pqxx::transaction_base &trans)
+void test_result_iteration()
 {
-  pqxx::result r = trans.exec("SELECT generate_series(1, 3)");
+  pqxx::connection conn;
+  pqxx::work tx{conn};
+  pqxx::result r = tx.exec("SELECT generate_series(1, 3)");
 
   PQXX_CHECK(r.end() != r.begin(), "Broken begin/end.");
   PQXX_CHECK(r.rend() != r.rbegin(), "Broken rbegin/rend.");
@@ -17,6 +19,7 @@ void test_result_iteration(pqxx::transaction_base &trans)
   PQXX_CHECK_EQUAL(r.front().front().as<int>(), 1, "Unexpected front().");
   PQXX_CHECK_EQUAL(r.back().front().as<int>(), 3, "Unexpected back().");
 }
-} // namespace
 
-PQXX_REGISTER_TEST(test_result_iteration)
+
+PQXX_REGISTER_TEST(test_result_iteration);
+} // namespace
