@@ -1,6 +1,5 @@
 #include "../test_helpers.hxx"
 
-using namespace std;
 using namespace pqxx;
 
 namespace
@@ -71,15 +70,14 @@ void test_subtransaction_aborts_implicitly(connection_base &conn)
 }
 
 
-void test_subtransaction(transaction_base &nontrans)
+void test_subtransaction()
 {
-  connection_base &conn(nontrans.conn());
-  nontrans.abort();
+  connection conn;
   test_subtransaction_commits_if_commit_called(conn);
   test_subtransaction_aborts_if_abort_called(conn);
   test_subtransaction_aborts_implicitly(conn);
 }
-}
 
 
-PQXX_REGISTER_TEST_T(test_subtransaction, nontransaction)
+PQXX_REGISTER_TEST(test_subtransaction);
+} // namespace
