@@ -1,6 +1,5 @@
 #include "../test_helpers.hxx"
 
-using namespace std;
 using namespace pqxx;
 using namespace pqxx::test;
 
@@ -23,7 +22,7 @@ void test_check_notreached()
   {
     // This is what we expect.
   }
-  if (!failed)
+  if (not failed)
     throw test_failure(__FILE__, __LINE__, "PQXX_CHECK_NOTREACHED is broken.");
 }
 
@@ -42,7 +41,7 @@ void test_check()
   catch (const test_failure &)
   {
   }
-  if (!failed) PQXX_CHECK_NOTREACHED("PQXX_CHECK failed to notice failure.");
+  if (not failed) PQXX_CHECK_NOTREACHED("PQXX_CHECK failed to notice failure.");
 }
 
 
@@ -51,7 +50,7 @@ void test_check_throws_exception()
 {
   // PQXX_CHECK_THROWS_EXCEPTION expects std::exception...
   PQXX_CHECK_THROWS_EXCEPTION(
-	throw exception(),
+	throw std::exception(),
 	"PQXX_CHECK_THROWS_EXCEPTION did not catch std::exception.");
 
   // ...or any exception type derived from it.
@@ -133,7 +132,7 @@ void test_check_throws()
   try
   {
     // If the test throws the wrong type, PQXX_CHECK_THROWS throws a failure.
-    PQXX_CHECK_THROWS(throw exception(), test_failure, "(expected)");
+    PQXX_CHECK_THROWS(throw std::exception(), test_failure, "(expected)");
     failed = false;
   }
   catch (const test_failure &)
@@ -156,7 +155,7 @@ void test_check_throws()
 }
 
 
-void test_test_helpers(transaction_base &)
+void test_test_helpers()
 {
   test_check_notreached();
   test_check();
@@ -224,7 +223,7 @@ void test_test_helpers(transaction_base &)
 	test_failure,
 	"PQXX_CHECK_BOUNDS did not detect empty interval.");
 }
+
+
+PQXX_REGISTER_TEST(test_test_helpers);
 } // namespace
-
-
-PQXX_REGISTER_TEST_NODB(test_test_helpers)
