@@ -2,16 +2,15 @@
 
 #include <pqxx/util>
 
-using namespace std;
 using namespace pqxx;
 
 namespace
 {
-void test_thread_safety_model(transaction_base &)
+void test_thread_safety_model()
 {
   const thread_safety_model model = describe_thread_safety();
 
-  if (model.safe_libpq && model.safe_kerberos)
+  if (model.safe_libpq and model.safe_kerberos)
     PQXX_CHECK_EQUAL(
 	model.description,
 	"",
@@ -22,6 +21,7 @@ void test_thread_safety_model(transaction_base &)
 	"",
 	"Thread-safety model is imperfect but lacks description.");
 }
-} // namespace
 
-PQXX_REGISTER_TEST_NODB(test_thread_safety_model)
+
+PQXX_REGISTER_TEST(test_thread_safety_model);
+} // namespace
